@@ -42,10 +42,10 @@ class KubernetesHook(BaseHook):
     """
     Creates Kubernetes API connection.
 
-    - use in cluster configuration by using ``extra__kubernetes__in_cluster`` in connection
-    - use custom config by providing path to the file using ``extra__kubernetes__kube_config_path``
+    - use in cluster configuration by using extra field ``in_cluster`` in connection
+    - use custom config by providing path to the file using extra field ``kube_config_path`` in connection
     - use custom configuration by providing content of kubeconfig file via
-        ``extra__kubernetes__kube_config`` in connection
+        extra field ``kube_config`` in connection
     - use default config by providing no extras
 
     This hook check for configuration option in the above order. Once an option is present it will
@@ -67,10 +67,12 @@ class KubernetesHook(BaseHook):
     :param disable_tcp_keepalive: Set to ``True`` if you want to disable keepalive logic.
     """
 
-    conn_name_attr = 'kubernetes_conn_id'
-    default_conn_name = 'kubernetes_default'
-    conn_type = 'kubernetes'
-    hook_name = 'Kubernetes Cluster Connection'
+    conn_name_attr = "kubernetes_conn_id"
+    default_conn_name = "kubernetes_default"
+    conn_type = "kubernetes"
+    hook_name = "Kubernetes Cluster Connection"
+
+    DEFAULT_NAMESPACE = "default"
 
     @staticmethod
     def get_connection_form_widgets() -> dict[str, Any]:
@@ -80,28 +82,25 @@ class KubernetesHook(BaseHook):
         from wtforms import BooleanField, StringField
 
         return {
-            "extra__kubernetes__in_cluster": BooleanField(lazy_gettext('In cluster configuration')),
-            "extra__kubernetes__kube_config_path": StringField(
-                lazy_gettext('Kube config path'), widget=BS3TextFieldWidget()
+            "in_cluster": BooleanField(lazy_gettext("In cluster configuration")),
+            "kube_config_path": StringField(lazy_gettext("Kube config path"), widget=BS3TextFieldWidget()),
+            "kube_config": StringField(
+                lazy_gettext("Kube config (JSON format)"), widget=BS3TextFieldWidget()
             ),
-            "extra__kubernetes__kube_config": StringField(
-                lazy_gettext('Kube config (JSON format)'), widget=BS3TextFieldWidget()
+            "namespace": StringField(lazy_gettext("Namespace"), widget=BS3TextFieldWidget()),
+            "cluster_context": StringField(lazy_gettext("Cluster context"), widget=BS3TextFieldWidget()),
+            "disable_verify_ssl": BooleanField(lazy_gettext("Disable SSL")),
+            "disable_tcp_keepalive": BooleanField(lazy_gettext("Disable TCP keepalive")),
+            "xcom_sidecar_container_image": StringField(
+                lazy_gettext("XCom sidecar image"), widget=BS3TextFieldWidget()
             ),
-            "extra__kubernetes__namespace": StringField(
-                lazy_gettext('Namespace'), widget=BS3TextFieldWidget()
-            ),
-            "extra__kubernetes__cluster_context": StringField(
-                lazy_gettext('Cluster context'), widget=BS3TextFieldWidget()
-            ),
-            "extra__kubernetes__disable_verify_ssl": BooleanField(lazy_gettext('Disable SSL')),
-            "extra__kubernetes__disable_tcp_keepalive": BooleanField(lazy_gettext('Disable TCP keepalive')),
         }
 
     @staticmethod
     def get_ui_field_behaviour() -> dict[str, Any]:
         """Returns custom field behaviour"""
         return {
-            "hidden_fields": ['host', 'schema', 'login', 'password', 'port', 'extra'],
+            "hidden_fields": ["host", "schema", "login", "password", "port", "extra"],
             "relabeling": {},
         }
 
@@ -123,17 +122,8 @@ class KubernetesHook(BaseHook):
         self.in_cluster = in_cluster
         self.disable_verify_ssl = disable_verify_ssl
         self.disable_tcp_keepalive = disable_tcp_keepalive
-
         self._is_in_cluster: bool | None = None
 
-        # these params used for transition in KPO to K8s hook
-        # for a deprecation period we will continue to consider k8s settings from airflow.cfg
-        self._deprecated_core_disable_tcp_keepalive: bool | None = None
-        self._deprecated_core_disable_verify_ssl: bool | None = None
-        self._deprecated_core_in_cluster: bool | None = None
-        self._deprecated_core_cluster_context: str | None = None
-        self._deprecated_core_config_file: str | None = None
-
     @staticmethod
     def _coalesce_param(*params):
         for param in params:
@@ -150,7 +140,12 @@ class KubernetesHook(BaseHook):
         return extras
 
     def _get_field(self, field_name):
-        if field_name.startswith('extra_'):
+        """
+        Prior to Airflow 2.3, in order to make use of UI customizations for extra fields,
+        we needed to store them with the prefix ``extra__kubernetes__``. This method
+        handles the backcompat, i.e. if the extra dict contains prefixed fields.
+        """
+        if field_name.startswith("extra__"):
             raise ValueError(
                 f"Got prefixed name {field_name}; please remove the 'extra__kubernetes__' prefix "
                 f"when using this method."
@@ -160,30 +155,12 @@ class KubernetesHook(BaseHook):
         prefixed_name = f"extra__kubernetes__{field_name}"
         return self.conn_extras.get(prefixed_name) or None
 
-    @staticmethod
-    def _deprecation_warning_core_param(deprecation_warnings):
-        settings_list_str = ''.join([f"\n\t{k}={v!r}" for k, v in deprecation_warnings])
-        warnings.warn(
-            f"\nApplying core Airflow settings from section [kubernetes] with the following keys:"
-            f"{settings_list_str}\n"
-            "In a future release, KubernetesPodOperator will no longer consider core\n"
-            "Airflow settings; define an Airflow connection instead.",
-            DeprecationWarning,
-        )
-
     def get_conn(self) -> client.ApiClient:
         """Returns kubernetes api session for use with requests"""
-        in_cluster = self._coalesce_param(
-            self.in_cluster, self.conn_extras.get("extra__kubernetes__in_cluster") or None
-        )
-        cluster_context = self._coalesce_param(
-            self.cluster_context, self.conn_extras.get("extra__kubernetes__cluster_context") or None
-        )
-        kubeconfig_path = self._coalesce_param(
-            self.config_file, self.conn_extras.get("extra__kubernetes__kube_config_path") or None
-        )
-
-        kubeconfig = self.conn_extras.get("extra__kubernetes__kube_config") or None
+        in_cluster = self._coalesce_param(self.in_cluster, self._get_field("in_cluster"))
+        cluster_context = self._coalesce_param(self.cluster_context, self._get_field("cluster_context"))
+        kubeconfig_path = self._coalesce_param(self.config_file, self._get_field("kube_config_path"))
+        kubeconfig = self._get_field("kube_config")
         num_selected_configuration = len([o for o in [in_cluster, kubeconfig, kubeconfig_path] if o])
 
         if num_selected_configuration > 1:
@@ -200,30 +177,6 @@ class KubernetesHook(BaseHook):
             self.disable_tcp_keepalive, _get_bool(self._get_field("disable_tcp_keepalive"))
         )
 
-        # BEGIN apply settings from core kubernetes configuration
-        # this section should be removed in next major release
-        deprecation_warnings: list[tuple[str, Any]] = []
-        if disable_verify_ssl is None and self._deprecated_core_disable_verify_ssl is True:
-            deprecation_warnings.append(('verify_ssl', False))
-            disable_verify_ssl = self._deprecated_core_disable_verify_ssl
-        # by default, hook will try in_cluster first. so we only need to
-        # apply core airflow config and alert when False and in_cluster not otherwise set.
-        if in_cluster is None and self._deprecated_core_in_cluster is False:
-            deprecation_warnings.append(('in_cluster', self._deprecated_core_in_cluster))
-            in_cluster = self._deprecated_core_in_cluster
-        if not cluster_context and self._deprecated_core_cluster_context:
-            deprecation_warnings.append(('cluster_context', self._deprecated_core_cluster_context))
-            cluster_context = self._deprecated_core_cluster_context
-        if not kubeconfig_path and self._deprecated_core_config_file:
-            deprecation_warnings.append(('config_file', self._deprecated_core_config_file))
-            kubeconfig_path = self._deprecated_core_config_file
-        if disable_tcp_keepalive is None and self._deprecated_core_disable_tcp_keepalive is True:
-            deprecation_warnings.append(('enable_tcp_keepalive', False))
-            disable_tcp_keepalive = True
-        if deprecation_warnings:
-            self._deprecation_warning_core_param(deprecation_warnings)
-        # END apply settings from core kubernetes configuration
-
         if disable_verify_ssl is True:
             _disable_verify_ssl()
         if disable_tcp_keepalive is not True:
@@ -296,41 +249,49 @@ class KubernetesHook(BaseHook):
     def core_v1_client(self) -> client.CoreV1Api:
         return client.CoreV1Api(api_client=self.api_client)
 
+    @cached_property
+    def custom_object_client(self) -> client.CustomObjectsApi:
+        return client.CustomObjectsApi(api_client=self.api_client)
+
     def create_custom_object(
         self, group: str, version: str, plural: str, body: str | dict, namespace: str | None = None
     ):
         """
         Creates custom resource definition object in Kubernetes
-
         :param group: api group
         :param version: api version
         :param plural: api plural
         :param body: crd object definition
         :param namespace: kubernetes namespace
         """
-        api = client.CustomObjectsApi(self.api_client)
-        if namespace is None:
-            namespace = self.get_namespace()
+        api: client.CustomObjectsApi = self.custom_object_client
+        namespace = namespace or self._get_namespace() or self.DEFAULT_NAMESPACE
+
         if isinstance(body, str):
             body_dict = _load_body_to_dict(body)
         else:
             body_dict = body
-        try:
-            api.delete_namespaced_custom_object(
-                group=group,
-                version=version,
-                namespace=namespace,
-                plural=plural,
-                name=body_dict["metadata"]["name"],
-            )
-            self.log.warning("Deleted SparkApplication with the same name.")
-        except client.rest.ApiException:
-            self.log.info("SparkApp %s not found.", body_dict['metadata']['name'])
+
+        # Attribute "name" is not mandatory if "generateName" is used instead
+        if "name" in body_dict["metadata"]:
+            try:
+                api.delete_namespaced_custom_object(
+                    group=group,
+                    version=version,
+                    namespace=namespace,
+                    plural=plural,
+                    name=body_dict["metadata"]["name"],
+                )
+
+                self.log.warning("Deleted SparkApplication with the same name")
+            except client.rest.ApiException:
+                self.log.info("SparkApplication %s not found", body_dict["metadata"]["name"])
 
         try:
             response = api.create_namespaced_custom_object(
                 group=group, version=version, namespace=namespace, plural=plural, body=body_dict
             )
+
             self.log.debug("Response: %s", response)
             return response
         except client.rest.ApiException as e:
@@ -349,8 +310,7 @@ class KubernetesHook(BaseHook):
         :param namespace: kubernetes namespace
         """
         api = client.CustomObjectsApi(self.api_client)
-        if namespace is None:
-            namespace = self.get_namespace()
+        namespace = namespace or self._get_namespace() or self.DEFAULT_NAMESPACE
         try:
             response = api.get_namespaced_custom_object(
                 group=group, version=version, namespace=namespace, plural=plural, name=name
@@ -360,14 +320,38 @@ class KubernetesHook(BaseHook):
             raise AirflowException(f"Exception when calling -> get_custom_object: {e}\n")
 
     def get_namespace(self) -> str | None:
-        """Returns the namespace that defined in the connection"""
+        """
+        Returns the namespace defined in the connection or 'default'.
+
+        TODO: in provider version 6.0, return None when namespace not defined in connection
+        """
+        namespace = self._get_namespace()
+        if self.conn_id and not namespace:
+            warnings.warn(
+                "Airflow connection defined but namespace is not set; returning 'default'.  In "
+                "cncf.kubernetes provider version 6.0 we will return None when namespace is "
+                "not defined in the connection so that it's clear whether user intends 'default' or "
+                "whether namespace is unset (which is required in order to apply precedence logic in "
+                "KubernetesPodOperator).",
+                DeprecationWarning,
+            )
+            return "default"
+        return namespace
+
+    def _get_namespace(self) -> str | None:
+        """
+        Returns the namespace that defined in the connection
+
+        TODO: in provider version 6.0, get rid of this method and make it the behavior of get_namespace.
+        """
         if self.conn_id:
-            connection = self.get_connection(self.conn_id)
-            extras = connection.extra_dejson
-            namespace = extras.get("extra__kubernetes__namespace", "default")
-            return namespace
+            return self._get_field("namespace")
         return None
 
+    def get_xcom_sidecar_container_image(self):
+        """Returns the xcom sidecar image that defined in the connection"""
+        return self._get_field("xcom_sidecar_container_image")
+
     def get_pod_log_stream(
         self,
         pod_name: str,
@@ -388,7 +372,7 @@ class KubernetesHook(BaseHook):
                 self.core_v1_client.read_namespaced_pod_log,
                 name=pod_name,
                 container=container,
-                namespace=namespace if namespace else self.get_namespace(),
+                namespace=namespace or self._get_namespace() or self.DEFAULT_NAMESPACE,
             ),
         )
 
@@ -409,7 +393,28 @@ class KubernetesHook(BaseHook):
             name=pod_name,
             container=container,
             _preload_content=False,
-            namespace=namespace if namespace else self.get_namespace(),
+            namespace=namespace or self._get_namespace() or self.DEFAULT_NAMESPACE,
+        )
+
+    def get_namespaced_pod_list(
+        self,
+        label_selector: str | None = "",
+        namespace: str | None = None,
+        watch: bool = False,
+        **kwargs,
+    ):
+        """
+        Retrieves a list of Kind pod which belong default kubernetes namespace
+        :param label_selector: A selector to restrict the list of returned objects by their labels
+        :param namespace: kubernetes namespace
+        :param watch: Watch for changes to the described resources and return them as a stream
+        """
+        return self.core_v1_client.list_namespaced_pod(
+            namespace=namespace or self._get_namespace() or self.DEFAULT_NAMESPACE,
+            watch=watch,
+            label_selector=label_selector,
+            _preload_content=False,
+            **kwargs,
         )
 
 
@@ -421,8 +426,8 @@ def _get_bool(val) -> bool | None:
     if isinstance(val, bool):
         return val
     elif isinstance(val, str):
-        if val.strip().lower() == 'true':
+        if val.strip().lower() == "true":
             return True
-        elif val.strip().lower() == 'false':
+        elif val.strip().lower() == "false":
             return False
     return None
